@@ -30,7 +30,7 @@ from azure.common.credentials import ServicePrincipalCredentials
 
 class SimpleContainerGroup:
 
-    """Summary
+    """Simplified Container Group with a Single container
     
     Attributes:
         - name (str): Description
@@ -50,7 +50,9 @@ class SimpleContainerGroup:
         - resource_group_name (str): resource group
         - restart_policy (str): Always/OnFailure/Never
         - tags (dict[str, str]): Azure tags
-        - state (string): state of container group (Accessed if already created, Created it is created here)
+        - state (string): state of container group 
+        (Accessed if already created, Provisionned if it is prepared, and Created if it is created)
+        - protected (True, bool): display env vars values or not
     """
 
     def __init__(
@@ -66,6 +68,7 @@ class SimpleContainerGroup:
         command=None,
         identity=None,
         restart_policy="Never",
+        env_vars=[],
     ):
         """
         Simple container group object with one instance
@@ -82,6 +85,7 @@ class SimpleContainerGroup:
             - command (None, str, optionnal): container entry point
             - identity (None, taz.auth.UserAssignedIdentity, optionnal): User managed identity to affect
             - restart_policy ("Never", str, optionnal): set restart policy of container
+            - env_vars (None, dict, optionnal):  environment variables dictionnary to set
         """
 
         self.generic_client = GenericClient(
@@ -98,7 +102,6 @@ class SimpleContainerGroup:
         self.image = image
         self.cpus = cpus
         self.mem = mem
-        self.env_vars = []
         self.identity = identity
         self.restart_policy = restart_policy
         self.os_type = OperatingSystemTypes.linux
@@ -106,6 +109,12 @@ class SimpleContainerGroup:
         self.group = None
         self.instances = []
         self.tags = tags
+        self.state = "Provisionned"
+        self.protected = True
+        self.env_vars = []
+
+        if env_vars:
+            self.set_env_vars(env_vars)
 
         if not self.image:
             self._get_group()
@@ -128,6 +137,16 @@ class SimpleContainerGroup:
         """
         self.env_vars.append(EnvironmentVariable(name=name, value=value))
 
+    def set_env_vars(self, vars):
+        """
+        set env vars from dictionary
+        
+        Args:
+            - vars (dict): env vars dictionary
+        """
+        for key, value in vars.items():
+            self.add_env_var(key, value)
+
     def set_cpus(self, cpus):
         """
         set cores number
@@ -196,6 +215,7 @@ class SimpleContainerGroup:
                 self.image.container_registry.get_credentials()
             ],
             identity=self.identity,
+            tags=self.tags,
         )
 
         self.client.container_groups.create_or_update(
@@ -267,12 +287,35 @@ class SimpleContainerGroup:
         instances = []
 
         for instance in self.instances:
+            events = []
+            vars = []
             try:
+                for var in instance.environment_variables:
+                    if self.protected is False:
+                        value = var.value
+                    else:
+                        value = "<protected>"
+                    vars.append({var.name: value})
+                for event in instance.instance_view.events:
+                    events.append(
+                        "{} {} {} {}".format(
+                            event.first_timestamp,
+                            event.last_timestamp,
+                            event.name,
+                            event.message,
+                        )
+                    )
                 state = instance.instance_view.current_state.state
             except:
                 state = "unknown"
             instances.append(
-                {"name": instance.name, "image": instance.image, "state": state}
+                {
+                    "name": instance.name,
+                    "image": instance.image,
+                    "state": state,
+                    "events": events,
+                    "vars": vars,
+                }
             )
 
         if self.group:
@@ -287,8 +330,8 @@ class SimpleContainerGroup:
                 "mem": self.mem,
                 "restart_policy": self.restart_policy,
                 "command": self.command,
-                "instances": instances,
                 "state": self.state,
                 "group_name": group_name,
+                "instances": instances,
             }
         )
