@@ -16,10 +16,15 @@ class AciViewTests(unittest.TestCase):
             cfg.aci["container_group_name"], cfg.aci["resource_group"],
         )
 
-    def test_10_exists(self):
+    def test_10_display(self):
         self.assertTrue(self.container_group is not None)
         print(self.container_group)
 
+    def test_15_display_unprotected(self):
+        self.assertTrue(self.container_group is not None)
+        self.container_group.protected = False
+        print(self.container_group)
+
     def test_20_list_logs(self):
         print(self.container_group.list_logs())
 
